@@ -26,10 +26,8 @@
 #include <kconfig.h>
 
 #include "settings.h"
-#include "backends/mixer_backend.h"
 #include "backends/kmix-backends.cpp"
 #include "core/ControlManager.h"
-#include "core/volume.h"
 
 /**
  * Some general design hints. Hierarchy is Mixer->MixDevice->Volume
@@ -66,7 +64,7 @@ MasterControl Mixer::_globalMasterPreferred;
  */
 /* static */ bool Mixer::dynamicBackendsPresent()
 {
-    for (const Mixer *mixer : qAsConst(s_mixers))
+    for (const Mixer *mixer : std::as_const(s_mixers))
     {
         if (mixer->isDynamic()) return (true);
     }
@@ -75,7 +73,7 @@ MasterControl Mixer::_globalMasterPreferred;
 
 /* static */ bool Mixer::pulseaudioPresent()
 {
-    for (const Mixer *mixer : qAsConst(s_mixers))
+    for (const Mixer *mixer : std::as_const(s_mixers))
     {
         if (mixer->getDriverName()=="PulseAudio") return (true);
     }
@@ -409,7 +407,7 @@ QString Mixer::getBaseName() const
 
 /* static */ Mixer *Mixer::getGlobalMasterMixerNoFalback()
 {
-    for (Mixer *mixer : qAsConst(s_mixers))
+    for (Mixer *mixer : std::as_const(s_mixers))
     {
         if (mixer!=nullptr && mixer->id()==_globalMasterCurrent.getCard())
             return mixer;
@@ -468,7 +466,7 @@ QString Mixer::getBaseName() const
 		return mixer->_mixerBackend->recommendedMaster();
 	}
 
-	for (const shared_ptr<MixDevice> md : qAsConst(mixer->_mixerBackend->m_mixDevices))
+    for (const shared_ptr<MixDevice> &md : std::as_const(mixer->_mixerBackend->m_mixDevices))
 	{
 		if (!md) continue; // invalid
 
@@ -516,7 +514,7 @@ void Mixer::setLocalMasterMD(const QString &devPK)
 shared_ptr<MixDevice> Mixer::find(const QString &mixdeviceID) const
 {
 	shared_ptr<MixDevice> mdRet;
-	for (const shared_ptr<MixDevice> md : qAsConst(_mixerBackend->m_mixDevices))
+    for (const shared_ptr<MixDevice> &md : std::as_const(_mixerBackend->m_mixDevices))
 	{
 		if (!md) continue; // invalid
 		if (md->id()==mixdeviceID)
