@@ -34,7 +34,6 @@
 #include "backends/mixer_backend.h"
 #include "core/MasterControl.h"
 #include "mixset.h"
-#include "core/GlobalConfig.h"
 #include "core/mixdevice.h"
 #include "dbus/dbusmixerwrapper.h"
 #include "kmixcore_export.h"
@@ -119,8 +118,6 @@ public:
     // Returns the name of the driver, e.g. "OSS" or "ALSA0.9"
     static QString driverName(int num);
 
-    static bool getBeepOnVolumeChange();
-
     /**
      * Returns an unique ID of the Mixer. It currently looks like "<soundcard_descr>::<hw_number>:<driver>"
      */
@@ -189,12 +186,12 @@ public:
 
     void commitVolumeChange( shared_ptr<MixDevice> md );
 
-public slots:
+public Q_SLOTS:
     void readSetFromHWforceUpdate() const;
 
     virtual void setBalance(int balance); // sets the m_balance (see there)
     
-signals:
+Q_SIGNALS:
     void newBalance(Volume& );
     void controlChanged(void); // TODO remove?
 
