@@ -25,9 +25,7 @@
 #include <qevent.h>
 #include <qframe.h>
 #include <QGridLayout>
-#include <QIcon>
 #include <QLayoutItem>
-#include <QPushButton>
 #include <QSizePolicy>
 
 // KDE
@@ -38,7 +36,6 @@
 
 // KMix
 #include "core/mixer.h"
-#include "core/ControlManager.h"
 #include "gui/dialogchoosebackends.h"
 #include "gui/guiprofile.h"
 #include "gui/kmixprefdlg.h"
@@ -302,7 +299,7 @@ Application: KMix (kmix), signal: Segmentation fault
 
 	const QStringList preferredMixersForSoundmenu = Settings::mixersForSoundMenu();
 	//qCDebug(KMIX_LOG) << "Launch with " << preferredMixersForSoundmenu;
-	for (Mixer *mixer : qAsConst(Mixer::mixers()))
+	for (Mixer *mixer : std::as_const(Mixer::mixers()))
 	{
 		bool useMixer = preferredMixersForSoundmenu.isEmpty() || preferredMixersForSoundmenu.contains(mixer->id());
 		if (useMixer) addMixer(mixer);
@@ -313,7 +310,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	// backends.
 	if (getMixers().isEmpty())
 	{
-		for (Mixer *mixer : qAsConst(Mixer::mixers()))
+		for (Mixer *mixer : std::as_const(Mixer::mixers()))
 		{
 			addMixer(mixer);
 		}
@@ -336,7 +333,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	//
 	// Maybe need a configuration option?
 
-	for (const Mixer *mixer : qAsConst(getMixers()))
+	for (const Mixer *mixer : std::as_const(getMixers()))
 	{
 		//qCDebug(KMIX_LOG) << "ADD? mixerId=" << mixer->id();
 		// Get the configured master control for the mixer.
@@ -363,9 +360,9 @@ Application: KMix (kmix), signal: Segmentation fault
 	} // loop over all cards
 
 	// Finally add all application streams
-	for (const Mixer *mixer : qAsConst(getMixers()))
+	for (const Mixer *mixer : std::as_const(getMixers()))
 	{
-		for (shared_ptr<MixDevice> md : qAsConst(mixer->getMixSet()))
+		for (shared_ptr<MixDevice> md : std::as_const(mixer->getMixSet()))
 		{
 			if (md->isApplicationStream()) addToMixSet(md);
 		}
